# Py - Geez Library

Core library of [The vckyou](https://github.com/vckyou/vckyou), a Pyrogram And Telethon based for your userbot.


[![PyPI - Version](https://img.shields.io/pypi/v/py-Geez?style=round)](https://pypi.org/project/py-Geez)    
[![PyPI - Downloads](https://img.shields.io/pypi/dm/py-Geez?label=DOWNLOADS&style=round)](https://pypi.org/project/py-Geez)    
[![Maintenance](https://img.shields.io/badge/Maintained%3F-yes-green.svg)](https://github.com/vckyou/vckyou/graphs/commit-activity)
[![Open Source Love svg2](https://badges.frapsoft.com/os/v2/open-source.svg?v=103)](https://github.com/vckyou/vckyou)
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat-square)](https://makeapullrequest.com)

# Installation
```bash
pip3 install -U py-Geez
```


See more working plugins on [the offical repository](https://github.com/vckyou/GeezProjects)!

> Made with ✨ by [@VCKYAZ](https://t.me/vckyaz).    


# License
[![License](https://www.gnu.org/graphics/gplv3-with-text-136x68.png)](LICENSE)   
TeamGeez is licensed under [GNU General Public License](https://www.gnu.org/licenses/agpl-3.0.html) v3 or later.

# Credits
*  [![Geez](https://img.shields.io/static/v1?label=Geez&message=Devs&color=critical)](https://t.me/vckyou)
*  [Dan](https://github.com/delivrance) for [Pyrogram](https://github.com/pyrogram/pyrogram)
*  [Lonami](https://github.com/LonamiWebs/) for [Telethon](https://github.com/LonamiWebs/Telethon)
